#
# spec file for package neochat
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _kf5_version 5.88.0
%bcond_without  released
Name:           neochat
Version:        23.08.2
Release:        1.1
Summary:        A chat client for Matrix, the decentralized communication protocol
License:        BSD-2-Clause AND GPL-3.0-only AND GPL-3.0-or-later
Group:          Productivity/Networking/Instant Messenger
URL:            https://apps.kde.org/neochat/
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  cmark
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
%if 0%{?suse_version} == 1500
BuildRequires:  gcc12-PIE
BuildRequires:  gcc12-c++
%endif
BuildRequires:  kf5-filesystem
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF5Config) >= %{_kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{_kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{_kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{_kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{_kf5_version}
BuildRequires:  cmake(KF5ItemModels) >= %{_kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{_kf5_version}
BuildRequires:  cmake(KF5Kirigami2) >= %{_kf5_version}
BuildRequires:  cmake(KF5KirigamiAddons) >= 0.7.2
BuildRequires:  cmake(KF5Notifications) >= %{_kf5_version}
BuildRequires:  cmake(KF5QQC2DesktopStyle) >= %{_kf5_version}
BuildRequires:  cmake(KF5Sonnet) >= %{_kf5_version}
BuildRequires:  cmake(KF5WindowSystem) >= %{_kf5_version}
BuildRequires:  cmake(KQuickImageEditor) >= 0.1
BuildRequires:  cmake(QCoro5Coro)
BuildRequires:  cmake(Qt5Core) >= 5.15.2
BuildRequires:  cmake(Qt5Gui) >= 5.15.2
BuildRequires:  cmake(Qt5Keychain)
BuildRequires:  cmake(Qt5Multimedia) >= 5.15.2
BuildRequires:  cmake(Qt5Quick) >= 5.15.2
BuildRequires:  cmake(Qt5QuickControls2) >= 5.15.2
BuildRequires:  cmake(Qt5Svg) >= 5.15.2
BuildRequires:  cmake(Qt5Widgets) >= 5.15.2
BuildRequires:  cmake(Quotient) >= 0.7.0
BuildRequires:  pkgconfig(libcmark)
Requires:       kirigami-addons
Requires:       kirigami2
Requires:       kitemmodels-imports
Requires:       kquickimageeditor-imports
Requires:       syntax-highlighting-imports
Requires:       qt5qmlimport(QtLocation.5) >= 15
Requires:       qt5qmlimport(QtPositioning.5) >= 15
Requires:       qt5qmlimport(org.kde.quickcharts.1) >= 0

%description
Neochat is a client for Matrix, the decentralized communication protocol for instant
messaging.

%lang_package

%prep
%autosetup -p1

%build
# c++-20 is required
%if 0%{?suse_version} == 1500
    export CC=gcc-12 CXX=g++-12
%endif

%cmake_kf5 -d build

%cmake_build

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang %{name} --all-name --with-man

%files
%license LICENSES/*
%doc README*
%dir %{_kf5_sharedir}/krunner/
%dir %{_kf5_sharedir}/krunner/dbusplugins/
%{_kf5_applicationsdir}/org.kde.neochat.desktop
%{_kf5_appstreamdir}/org.kde.neochat.appdata.xml
%{_kf5_bindir}/neochat
%{_kf5_debugdir}/neochat.categories
%{_kf5_iconsdir}/hicolor/*/apps/org.kde.neochat.svg
%{_kf5_iconsdir}/hicolor/scalable/apps/org.kde.neochat.tray.svg
%{_kf5_mandir}/man1/neochat.1%{?ext_man}
%{_kf5_notifydir}/neochat.notifyrc
%{_kf5_sharedir}/krunner/dbusplugins/plasma-runner-neochat.desktop

%files lang -f %{name}.lang

%changelog
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Use shortcode as a fallback for body when sending stickers
  * Add cmake check for qtlocation QML module
  * Add Windows-specific screenshots as screenshots with custom attribute
  * Deselect space when leaving it (kde#473271)
  * Fix opening settings (kde#473789)
  * Fix opening report sheet
  * Force plain text user display name in user detail sheet
  * Fix opening ban sheet
  * Add release note for last two version
  * Remove debuging value
* Mon Sep  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add some qt5qmlimport runtime deps (boo#1214916)
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- Changes since 23.07.90:
  * Don't inherit color in TimelineContainer
  * Use view-list-details instead of expand icon in room drawer
  * Destroy the correct component in space list context menu
  * Prevent the TapHandler in AvatarTabButton from triggering clicked()
  * Add icons to the space list context menu items
  * Prevent the chat bar from pasting a local file URL if we save the bitmap
  * Ensure that the notification avatar is drawn with no pen
  * Further notification avatar improvements
  * Fix the account switcher width so it doesn't spill off the side
  * Pick a better shadow and clean up emoji popup backgrounds
  * Don't clip the emoji popups as they destroy shadows
  * Improve tooltips in chatbar
  * Wrap room display name in Room Drawer
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Display big emoji correctly
  * Force plain text in room delegate
  * Remove leftover debug statement
  * Fix last active time in devices page
  * Redesign timeline
  * Fix opening account menu on right click
  * Html-escape display names in state delegates
  * Fix room list icon size in compact room list (kde#472682)
  * Fix compilation with e2ee disabled
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Too many changes since 23.04.3, only listing bugfixes:
  * Fix toolbar of RoomList when using font size 11px (kde#467242)
  * Don't try getting data for invalid indices (kde#470639)
  * Refactor login (kde#469486)
  * Improve Delegate Width Sizing (kde#470167)
  * Fix replying and editing from chatbox (kde#469733)
  * Fix the room timeline being dragged when selecting text (kde#467163)
  * Focus message search window's search field by default (kde#469879)
  * Cache last event (kde#455042)
  * Add more bottom margin (kde#469616)
  * Fix autocompletion not working (kde#468967)
  * Remove Unread Count (kde#466515)
  * Fix regressions from RoomPage refactoring (kde#469427)
  * Improve RoomDrawer for direct chats (kde#466895)
  * Prevent crash in SyntaxHighlighter when leaving room (kde#467722)
  * Fix handling line separators (kde#468977)
  * Fix Ctrl+Shift+, opening settings (kde#469057)
  * Fix room search field shortcut (kde#469059)
  * Fix Chat bubble background changing color when created (kde#468124)
  * Fix Long Topics in the RoomDrawer Overflowing (kde#467512)
  * Don't crash in UserListModel when there is no room (kde#466045)
  * Fix state event visiblity in timeline (kde#455048)
  * Improve Text Handling (kde#463932)
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Focus message search window's search field by default (kde#469879)
  * Fix asan runtime error in texthandler
  * Update appstream description
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Don't enforce tests on windows Qt6
  * Fix handling line separators (kde#468977)
  * Prevent crash in SyntaxHighlighter when leaving room (kde#467722)
  * Add loading title to LoadingPage
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Wed Feb 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.01.0
  * notifications are now shown for all accounts
  * new compact mode for the room list
  * searching in history is now possible
  * emojis and reactions improvements
* Mon Jan 23 2023 Tamara Schmitz <tschmitz@suse.com>
- update to 22.11:
  * work on end-to-end encryption implementation
  * configuration settings ported to new form components
  * new settings component for managing notifications settings
  * add proxy configuration menu
  * added developer tools for inspecting raw matrix events
  * added confirmation dialog when signing out and when enabling end-to-end encryption
  * rewrite of theaccount switcher
- fix buildrequires, remove redundant requires
- fix permissions of license file
* Thu Sep 29 2022 Dirk Müller <dmueller@suse.com>
- update to 22.09:
  * implemented support for configuring notifications on a per-room basis. As
    part of his GSoC project, Snehit added a space selector to the room list,
    which allows filtering the room list for rooms included in the selected
    space. James also reworked the timeline layout to make it look nicer when
    the window is very wide. There have also been a ton of other fixes and
    improvements in translations, the layout and the stability of NeoChat.
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Use GCC 10 to build neochat on Leap.
* Wed Aug  3 2022 Dirk Müller <dmueller@suse.com>
- update to 22.06:
  * Sending of typing notifications can now be disabled.
  * In the room list, the scrollbar will now disappear correctly when it is not needed.
  * On wayland, NeoChat will now raise correctly when clicking on a notification.
  * Several bugs have been fixed that would sometimes cause messages containing
    markdown and/or HTML elements to be sent incorrectly.
  * The quick switcher can now be controlled using the mouse.
  * There is now an option to disable automatic room sidebar opening when
    resizing the window.
  * Creation of custom emojis has been fixed.
  * Editing or replying to the last message using the keyboard shortcuts now
    works correctly.
  * When switching between rooms using the keyboard, the switching direction is
    now correct.
* Tue Mar 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update the QCoro build dependency.
* Wed Feb  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 22.02:
  * Implement sharing with Purpose (export)
  * Implement adding labels for account
  * Give settings window a title
  * Reduce minimum height of the window
  * Fix build with qcoro 0.4
  * Fix issues with saveFileAs
  * Changed “Settings” to “Configure NeoChat” in menu
  * Improve toolbar on mobile
  * Improve emoji pane
  * Check if password can be changed
  * Fix image tooltip
  * Adapt list setting pages to new style
  * Allow using ESC to go back to room list
  * Port away from QNetworkConfigurationManager
  * Remove lag when starting user autocompletion
  * Set single window hint in desktop file
  * Make room address selectable
  * Display monochrome icon in tray
  * Fix QuickSwitcher activation
  * Fix Windows/mac build
  * Fix notifications on Android
  * Support raising when we receive a notification
  * Don’t render html in RoomDrawer heading
  * Add support for minimizing to system tray on startup
  * Use non blocking passord reading
  * Add a mobile oriented context menu for the room list
  * Fix loading room settings on mobile
  * Use icon from qrc for system tray icon
  * Adapt to libQuotient API change
* Mon Feb  7 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 21.12:
  * Solved various problems related to login, logout and account switching
  * Fixed a few problems in the timeline layout
  * Added Spell checking while writing a message
  * Improved Settings pages
  * Many improvements to the android and general mobile support
  * Show blurhashes while images load
  * Support showing custom emojis
  * Added a global menu
  * Added support for spoilers
  * Added a quick switcher to switch between rooms
  * Added support for an optional fancy blur background effect
  * Resizable left and right drawers
  * Added Syntax highlighting in raw json messages
  * Better wayland support
  * Improved file reception and download
- Part of Plasma Mobile Gear now, adjust URL and neochat.keyring
* Sat Jun 26 2021 ecsos <ecsos@opensuse.org>
- Fix build error.
  - Add missig cmark which will not be install with libcmark-devel.
* Tue Jun  1 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.2.0
  * major UI redesign
  * chage page is now using bubbles
  * it's now possible to send custom reactions by replying
    to a comment with /react <message>
  * now supports opening Matrix URI from the web browser
* Thu Feb 25 2021 ecsos <ecsos@opensuse.org>
- Update to 1.1.1
  - First launch experience improvements
  - Allow logins to servers requiring SSO
  - Display stickers
  - Allow editing messages
  - Multimodal mode to open a room into a new window
  - New chat commands
  - Better Plasma integration
* Mon Feb 15 2021 Tomas Cech <sleep_walker@opensuse.org>
- Add missing require libqt5-qtquickcontrols again.
* Sat Jan 16 2021 Luca Beltrame <lbeltrame@kde.org>
- Adjust spec file to conform to the KDE team's guidelines
* Wed Jan 13 2021 ecsos <ecsos@opensuse.org>
- Update to 1.0.1
  - NeoChat doesn't require a .well-know configuration in the
    server to work.
  - Edited messages won’t show up duplicated anymore.
  - NeoChat now ask for consent to terms and conditions if required
    instead of displaying nothing.
  - Users avatar in the room list are now displayed correctly.
  - Fix image saving
  - Various graphic glitches have been fixed.
- Switch source from invent.kde.org to download.kde.org, because in
  git is not always the newest tar.
- Add language subpackages.
* Mon Jan  4 2021 ecsos <ecsos@opensuse.org>
- Add missing require libqt5-qtquickcontrols.
* Wed Dec 23 2020 ecsos <ecsos@opensuse.org>
- Change from git version to version 1.0
* Mon Nov 23 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
